==> haskell-syb-0.6-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: syb
version: 0.6
id: syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
key: syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
license: BSD3
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
synopsis: Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
exposed: True
exposed-modules:
    Data.Generics Data.Generics.Basics Data.Generics.Instances
    Data.Generics.Aliases Data.Generics.Schemes Data.Generics.Text
    Data.Generics.Twins Data.Generics.Builders Generics.SYB
    Generics.SYB.Basics Generics.SYB.Instances Generics.SYB.Aliases
    Generics.SYB.Schemes Generics.SYB.Text Generics.SYB.Twins
    Generics.SYB.Builders
abi: 200869a20808ef88b48c7eefd21ccf56
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/syb-0.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/syb-0.6
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/syb-0.6
hs-libraries: HSsyb-0.6-IcoSwlPi2Nx4zSqMmorFPS
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html: /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-syb-0.7-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: syb
version: 0.7
id: syb-0.7-4OKdCpwGutyB1rNRmoa0ya
key: syb-0.7-4OKdCpwGutyB1rNRmoa0ya
license: BSD3
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
synopsis: Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
exposed: True
exposed-modules:
    Data.Generics Data.Generics.Basics Data.Generics.Instances
    Data.Generics.Aliases Data.Generics.Schemes Data.Generics.Text
    Data.Generics.Twins Data.Generics.Builders Generics.SYB
    Generics.SYB.Basics Generics.SYB.Instances Generics.SYB.Aliases
    Generics.SYB.Schemes Generics.SYB.Text Generics.SYB.Twins
    Generics.SYB.Builders
abi: caee639019191603b5b5d3eceb365967
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/syb-0.7
library-dirs: /usr/lib/ghc-8.0.2/site-local/syb-0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/syb-0.7
hs-libraries: HSsyb-0.7-4OKdCpwGutyB1rNRmoa0ya
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html: /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
